@@ -3,6 +3,16 @@ from scipy.interpolate import InterpolatedUnivariateSpline
 from scipy.optimize import brentq
 import matplotlib.pyplot as plt
 
+KWT = {0:0.114e-14, 10:0.681e-14, 20: 0.929e-14, 25: 1.008e-14, 30: 1.469e-14, 40: 2.919e-14, 50: 5.474e-14, 60: 9.610e-14}
+
+class KW_T(object):
+    def __init__(self,werte=KWT):
+        werte = sorted(werte.items())
+        self.spline = InterpolatedUnivariateSpline([x for (x,y) in werte],[y for (x,y) in werte])
+
+    def __call__(self,t):
+        return float(self.spline(t))
+
 class Solute(object):
     def __init__(self,KS,CS=1,acid=True):
         '''
@@ -72,6 +82,7 @@ class Solute(object):
         return charge 
 
 
+
 class Solution(object):
 
     def __init__(self,*solutes):
@@ -217,7 +228,7 @@ class Titration(Solution):
         # to_titrate (one solute) is variable, all other solutes are fixed
         Solution.__init__(self,*solutes)
         self.precision = 1000
-        self.delta = 1.0/plot_precision
+        self.delta = 1.0/self.precision
 
     def compute_PH(self,V_titrate):
         '''
@@ -272,3 +283,8 @@ class Titration(Solution):
         plt.title('Titration Curve')
         plt.show()
 
+if __name__ == "__main__":
+    acid = Solute(KS = [5.01e-7], CS = 2, acid = True) 
+    base = Solute(KS = [0.63], CS = 5, acid = False)
+    titration = Titration(base, acid)
+    titration.plot_titration(15, 25) 
